<p align="center">
    <a href="https://github.com/klukashka/Vaultx">
    <img src="https://github.com/user-attachments/assets/f9b82311-e1ec-4cf2-8792-3c0d9a7ab8c1" alt="Vaultx"> </a>
</p>
<p align="center">
    <em>Vaultx library is a Python 3.x client for HashiCorp's Vault. It is based on httpx and provides both sync and async clients</em>
</p>

<p align="center">
  <img src="https://github.com/klukashka/Vaultx/actions/workflows/run_tests.yml/badge.svg" alt="Tests status">
  <img src="https://klukashka.github.io/Vaultx/coverage.svg" alt="Coverage">
  <img src="https://img.shields.io/pypi/pyversions/Vaultx?color=dark-green" alt="Supported Python versions">
  <img src="https://img.shields.io/badge/Supported%20OS-Windows%2C%20macOS%2C%20Linux-default" alt="Supported OS">
  <img src="https://static.pepy.tech/badge/Vaultx/month" alt="Downloads per month">
</p>

---
**Documentation:** <https://klukashka.github.io/Vaultx/>

**Source code:**: <https://github.com/klukashka/Vaultx/>

---

## Installation

```shell
pip install vaultx
```

>**Note**: Vaultx is inspired by [hvac](https://github.com/hvac/hvac). Architecture and interface are taken from there.

## Features

* Supports async
* Based on [httpx](https://github.com/encode/httpx)
* Supports [hvac](https://github.com/hvac/hvac) interface
* Faster than [hvac](https://github.com/hvac/hvac)

## Documentation
* [Overview](https://klukashka.github.io/Vaultx/)
* [Getting Started](https://klukashka.github.io/Vaultx/overview/getting_started)
* [Usage](https://klukashka.github.io/Vaultx/usage/)
* [Async Support](https://klukashka.github.io/Vaultx/overview/async_support)
* [Contribute](https://klukashka.github.io/Vaultx/contribute/guidelines/)

## Contributing
If you want to contribute, follow the [Contribution Guide](https://klukashka.github.io/Vaultx/contribute/guidelines/).